==> comet_ml-3.39.0-py3-none-any.whl: comet_ml/error_tracking/environment_details.py <==
# -*- coding: utf-8 -*-
# *******************************************************
#   ____                     _               _
#  / ___|___  _ __ ___   ___| |_   _ __ ___ | |
# | |   / _ \| '_ ` _ \ / _ \ __| | '_ ` _ \| |
# | |__| (_) | | | | | |  __/ |_ _| | | | | | |
#  \____\___/|_| |_| |_|\___|\__(_)_| |_| |_|_|
#
#  Sign up for free at https://www.comet.com
#  Copyright (C) 2015-2021 Comet ML INC
#  This file can not be copied and/or distributed without the express
#  permission of Comet ML Inc.
# *******************************************************

import functools
import logging
import os
import sys
from typing import Any, Dict, Optional

from comet_ml import _jupyter, env_logging, oscontainer, utils

import psutil

LOGGER = logging.getLogger(__name__)


def collect() -> Dict[str, Any]:
    """Return environment details without personally identifiable information"""

    result = {
        "pid": env_logging.get_pid(),
        "os": env_logging.get_os(),
        "os_type": env_logging.get_os_type(),
        "python_version_verbose": env_logging.get_python_version_verbose(),
        "python_version": env_logging.get_python_version(),
        "user": env_logging.get_user(),
        "python_exe": sys.executable,
        "sdk_version": env_logging.get_comet_version(),
        "jupyter": _jupyter._in_jupyter_environment(),
        "colab": _jupyter._in_colab_environment(),
        "aws_lambda": utils.is_aws_lambda_environment(),
        "container_detected": _container_detected(),
        "github_actions": _is_github_actions(),
        "cpu_count": psutil.cpu_count(),
        "cuda_visible_devices": _get_cuda_visible_devices(),
    }

    installed_packages_details = _get_installed_packages_details()
    result.update(installed_packages_details)

    return result


@functools.lru_cache(maxsize=1)
def _container_detected():
    return oscontainer.OSContainer().is_containerized()


def _is_github_actions():
    return "GITHUB_ACTIONS" in os.environ


def _get_cuda_visible_devices() -> Optional[str]:
    return (
        os.environ["CUDA_VISIBLE_DEVICES"]
        if "CUDA_VISIBLE_DEVICES" in os.environ
        else None
    )


def _get_installed_packages_details() -> Dict[str, str]:
    packages = env_logging.get_pip_packages(as_tuples=True)
    OBSERVED = ["pytorch", "tensorflow", "numpy"]

    result = {}
    for name, version in packages:
        if name in OBSERVED:
            result[name] = version

    return result


def try_get_cloud_provider() -> Optional[str]:
    """
    get_env_cloud_details can take time, we want to
    use it only if it was already called before and the result
    was saved in cache (e.g. after an experiment is created).

    It also means that there is no sense to call it at the beginning of the script.
    """
    try:
        cache_info = env_logging.get_env_cloud_details.cache_info()

        if cache_info.currsize > 0:
            details = env_logging.get_env_cloud_details()
            if details is not None:
                return details["provider"]
    except Exception:
        LOGGER.debug("Failed to get cloud provider data", exc_info=True)

    return None

==> comet_ml-3.39.1-py3-none-any.whl: comet_ml/error_tracking/environment_details.py <==
# -*- coding: utf-8 -*-
# *******************************************************
#   ____                     _               _
#  / ___|___  _ __ ___   ___| |_   _ __ ___ | |
# | |   / _ \| '_ ` _ \ / _ \ __| | '_ ` _ \| |
# | |__| (_) | | | | | |  __/ |_ _| | | | | | |
#  \____\___/|_| |_| |_|\___|\__(_)_| |_| |_|_|
#
#  Sign up for free at https://www.comet.com
#  Copyright (C) 2015-2021 Comet ML INC
#  This file can not be copied and/or distributed without the express
#  permission of Comet ML Inc.
# *******************************************************

import functools
import logging
import os
import sys
from typing import Any, Dict, Optional

from comet_ml import _jupyter, env_logging, oscontainer, utils

import psutil

LOGGER = logging.getLogger(__name__)


def collect_context() -> Dict[str, Any]:
    """Return environment details without personally identifiable information"""

    result = {
        "pid": env_logging.get_pid(),
        "os": env_logging.get_os(),
        "python_version_verbose": env_logging.get_python_version_verbose(),
        "python_exe": sys.executable,
        "container_detected": _container_detected(),
        "github_actions": _is_github_actions(),
        "cpu_count": psutil.cpu_count(),
        "cuda_visible_devices": _get_cuda_visible_devices(),
    }

    installed_packages_details = _get_installed_packages_details()
    result.update(installed_packages_details)

    return result


def collect_tags():
    """
    Tags are close to context but can be used for filtering and search
    in Sentry
    """
    result = {
        "os_type": env_logging.get_os_type(),
        "python_version": env_logging.get_python_version(),
        "release": env_logging.get_comet_version(),
        "jupyter": _jupyter._in_jupyter_environment(),
        "colab": _jupyter._in_colab_environment(),
        "aws_lambda": utils.is_aws_lambda_environment(),
    }

    return result


@functools.lru_cache(maxsize=1)
def _container_detected():
    return oscontainer.OSContainer().is_containerized()


def _is_github_actions():
    return "GITHUB_ACTIONS" in os.environ


def _get_cuda_visible_devices() -> Optional[str]:
    return (
        os.environ["CUDA_VISIBLE_DEVICES"]
        if "CUDA_VISIBLE_DEVICES" in os.environ
        else None
    )


def _get_installed_packages_details() -> Dict[str, str]:
    packages = env_logging.get_pip_packages(as_tuples=True)
    OBSERVED = ["pytorch", "tensorflow", "numpy"]

    result = {}
    for name, version in packages:
        if name in OBSERVED:
            result[name] = version

    return result


def try_get_cloud_provider() -> Optional[str]:
    """
    get_env_cloud_details can take time, we want to
    use it only if it was already called before and the result
    was saved in cache (e.g. after an experiment is created).

    It also means that there is no sense to call it at the beginning of the script.
    """
    try:
        cache_info = env_logging.get_env_cloud_details.cache_info()

        if cache_info.currsize > 0:
            details = env_logging.get_env_cloud_details()
            if details is not None:
                return details["provider"]
    except Exception:
        LOGGER.debug("Failed to get cloud provider data", exc_info=True)

    return None
